@@ -42,7 +42,8 @@ sub _deduce {
     my $cobj    = B::svref_2object($code);
     my $pkg     = $cobj->GV->STASH->NAME;
     my $file    = $cobj->FILE;
-    my $line    = $cobj->START->line;
+    my $start   = $cobj->START;
+    my $line    = $start->can('line') ? $start->line : -1;
     my $subname = $cobj->GV->NAME;
 
     $SUB_MAPS{$file}->{$line} = $self->{+NAME};
@@ -55,17 +56,9 @@ sub package { $_[0]->{+DEDUCED}->[PACKAGE] }
 sub file    { $_[0]->{+DEDUCED}->[FILE]    }
 sub subname { $_[0]->{+DEDUCED}->[SUBNAME] }
 
-sub run {
-    my $self = shift;
-    my @args = @_;
-
-    $self->{+CODEREF}->(@args);
-}
-
-sub detail {
+sub call_detail {
     my $self = shift;
 
-    my $name = $self->{+NAME};
     my $file = $self->file;
 
     my $start = $self->start_line;
@@ -83,12 +76,21 @@ sub detail {
         $lines = "line $start (declared in $dfile line $dline)";
     }
 
+    return "$file $lines";
+}
+
+sub detail {
+    my $self = shift;
+
+    my $name  = $self->{+NAME};
+    my $lines = $self->call_detail;
+
     my $known = "";
     if ($self->{+DEDUCED}->[SUBNAME] ne '__ANON__') {
         $known = " (" . $self->{+DEDUCED}->[SUBNAME] . ")";
     }
 
-    return "${name}${known} in ${file} ${lines}";
+    return "${name}${known} in $lines";
 }
 
 sub start_line {
@@ -222,7 +224,7 @@ experimental phase is over.
 =head1 DESCRIPTION
 
 This module is used to find line numbers, files, and other data about
-codeblocks. When used properly you can get botht he start and end lines of
+codeblocks. When used properly you can get both the start and end lines of
 codeblocks.
 
 =head1 SYNOPSIS
