@@ -2,7 +2,7 @@ package Test::Stream::Event::Bail;
 use strict;
 use warnings;
 
-use Test::Stream::TAP qw/OUT_STD/;
+use Test::Stream::Formatter::TAP qw/OUT_STD/;
 
 use Test::Stream::Event(
     accessors => [qw/reason/],
@@ -78,10 +78,6 @@ Inherits from L<Test::Stream::Event>. Also defines:
 
 The reason for the bailout.
 
-=item $bool = quiet
-
-Should the bailout be quiet?
-
 =back
 
 =head1 SOURCE
